==> haskell-insert-ordered-containers-0.2.1.0-44-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-9PxvsXUYNKmAj2s7sWPKrN
key: insert-ordered-containers-0.2.1.0-9PxvsXUYNKmAj2s7sWPKrN
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: 75bc09804c5d9c9025c8f5357f68f06a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-9PxvsXUYNKmAj2s7sWPKrN
depends:
    base-4.10.1.0 aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    lens-4.15.4-7QG8mYr23Bj1pOefi9ypZY
    semigroupoids-5.2.2-6gyDXeDCUP0EyLlIzFD0yC
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo=6be681d1d865a75a35865349e66ae8da
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             lens-4.15.4-7QG8mYr23Bj1pOefi9ypZY=1fa3c917f03ff2177e4bebc838538479
             semigroupoids-5.2.2-6gyDXeDCUP0EyLlIzFD0yC=6a2158de4030a7102bc33e2f5f7a8e7b
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.1.0-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-dzmvpxLGH68P0oRjgYW97
key: insert-ordered-containers-0.2.1.0-dzmvpxLGH68P0oRjgYW97
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: ef16cccf48da6354cfe0bb310ae92550
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-dzmvpxLGH68P0oRjgYW97
depends:
    base-4.10.1.0 aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    lens-4.15.4-8VElApQlNdSC7zfU0AKr8J
    semigroupoids-5.2.2-EUoCVHA4Dj6p1XuIsiYdq
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             aeson-1.2.3.0-FF3lFd58LTtGOe8yOI27Zo=6be681d1d865a75a35865349e66ae8da
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             lens-4.15.4-8VElApQlNdSC7zfU0AKr8J=3fc6957787002c0dde8bc9e06a51d485
             semigroupoids-5.2.2-EUoCVHA4Dj6p1XuIsiYdq=382c1c37882bd2c3260ce8898a4881ce
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
